## 🚀 Change Type
- [ ] ✨ New Feature
- [ ] 🐞 Bug Fix
- [ ] 🔧 Refactor/Maintenance
- [ ] 📚 Documentation

## 📝 Description of Changes

## 🧪 Testing Verification
- [ ] Verified in local environment (Local GNS3/Nornir Test)
- [ ] Run pytest and passed
- [ ] mypy and ruff checks passed

## 🔗 Related Issues
Fixes #
